@@ -28,11 +28,13 @@ from typing import Optional, Any
 
 from pyee import AsyncIOEventEmitter    # type: ignore
 
+from wechaty_puppet.schemas.base import BaseDataClass
+
 log = logging.getLogger('Watchdog')
 
 
-@dataclass
-class WatchdogFood:
+@dataclass(init=False)
+class WatchdogFood(BaseDataClass):
     """watchdog food interface"""
     timeout: int
     data: Optional[Any] = None
@@ -46,7 +48,7 @@ class Watchdog(AsyncIOEventEmitter):
         """
         init the watch dog
         """
-        super(Watchdog, self).__init__()
+        super().__init__()
         self._last_feed: Optional[datetime] = None
         self._last_food: Optional[WatchdogFood] = None
         self.default_timeout: int = default_timeout
